Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/phpmyadmin/phpmyadmin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ChangeLog6
-rw-r--r--Documentation.html4
-rw-r--r--index.php4
-rw-r--r--js/querywindow.js4
-rw-r--r--libraries/common.lib.php4
-rw-r--r--navigation.php (renamed from left.php)20
-rw-r--r--scripts/setup.php10
7 files changed, 29 insertions, 23 deletions
diff --git a/ChangeLog b/ChangeLog
index 850236759f..6c63163065 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -5,6 +5,12 @@ phpMyAdmin - ChangeLog
$Id$
$HeadURL$
+2006-10-16 Michal Čihař <michal@cihar.com>
+ * left.php, navigation.php, scripts/setup.php, js/querywindow.js,
+ Documentation.html, index.php, libraries/common.lib.php: Rename left.php
+ to navigation.php and modify all calls to that. Only config variables
+ are kept as Left*.
+
2006-10-14 Marc Delisle <lem9@users.sourceforge.net>
* export.php, db_details_export.php: bug #1541189, views are not displayed
in export list;
diff --git a/Documentation.html b/Documentation.html
index 865683b6f2..32747434bd 100644
--- a/Documentation.html
+++ b/Documentation.html
@@ -2253,7 +2253,7 @@ ALTER TABLE `pma_column_comments`
time there is no better fix): remove or comment the <tt>DOCTYPE</tt>
declarations (2 lines) from the scripts <i>libraries/header.inc.php</i>,
<i>libraries/header_printview.inc.php</i>, <i>index.php</i>,
- <i>left.php</i> and <i>libraries/common.lib.php</i>.</p>
+ <i>navigation.php</i> and <i>libraries/common.lib.php</i>.</p>
<h4 id="faq1_7">
<a href="#faq1_7">1.7 How can I GZip or Bzip a dump or a
@@ -2589,7 +2589,7 @@ SetInputFilter PHP
</pre>
<h4 id="faq1_30">
- <a href="#faq1_30">1.30 I get the error &quot;left.php: Missing hash&quot;.</a></h4>
+ <a href="#faq1_30">1.30 I get the error &quot;navigation.php: Missing hash&quot;.</a></h4>
<p> This problem is known to happen when the server is running Turck MMCache
but upgrading MMCache to version 2.3.21 solves the problem.</p>
diff --git a/index.php b/index.php
index 44681a8d5c..d40d601879 100644
--- a/index.php
+++ b/index.php
@@ -144,7 +144,7 @@ if ($GLOBALS['text_dir'] === 'ltr') {
?>" rows="*" id="mainFrameset">
<?php if ($GLOBALS['text_dir'] === 'ltr') { ?>
<frame frameborder="0" id="frame_navigation"
- src="left.php<?php echo $url_query; ?>"
+ src="navigation.php<?php echo $url_query; ?>"
name="frame_navigation" />
<?php } ?>
<frame frameborder="0" id="frame_content"
@@ -152,7 +152,7 @@ if ($GLOBALS['text_dir'] === 'ltr') {
name="frame_content" />
<?php if ($GLOBALS['text_dir'] === 'rtl') { ?>
<frame frameborder="0" id="frame_navigation"
- src="left.php<?php echo $url_query; ?>"
+ src="navigation.php<?php echo $url_query; ?>"
name="frame_navigation" />
<?php } ?>
<noframes>
diff --git a/libraries/common.lib.php b/libraries/common.lib.php
index eb113fcd42..7fc3a84833 100644
--- a/libraries/common.lib.php
+++ b/libraries/common.lib.php
@@ -1201,7 +1201,7 @@ if (!defined('PMA_MINIMUM_COMMON')) {
// Reloads the navigation frame via JavaScript if required
if (isset($GLOBALS['reload']) && $GLOBALS['reload']) {
echo "\n";
- $reload_url = './left.php?' . PMA_generate_common_url((isset($GLOBALS['db']) ? $GLOBALS['db'] : ''), '', '&');
+ $reload_url = './navigation.php?' . PMA_generate_common_url((isset($GLOBALS['db']) ? $GLOBALS['db'] : ''), '', '&');
?>
<script type="text/javascript" language="javascript">
//<![CDATA[
@@ -2583,7 +2583,7 @@ $goto_whitelist = array(
'export.php',
'import.php',
//'index.php',
- //'left.php',
+ //'navigation.php',
//'license.php',
'main.php',
'pdf_pages.php',
diff --git a/scripts/setup.php b/scripts/setup.php
index d87b19c104..b2a423b2f3 100644
--- a/scripts/setup.php
+++ b/scripts/setup.php
@@ -1005,7 +1005,7 @@ function show_left_form($defaults = array()) {
?>
<form method="post" action="">
<?php echo get_hidden_inputs();?>
- <input type="hidden" name="action" value="lay_left_real" />
+ <input type="hidden" name="action" value="lay_navigation_real" />
<?php
echo get_hidden_cfg();
show_config_form(array(
@@ -1018,7 +1018,7 @@ function show_left_form($defaults = array()) {
array('Display servers selection', 'LeftDisplayServers', 'Whether to show server selection in left frame', FALSE),
array('Enable pointer highlighting', 'LeftPointerEnable', 'Whether you want to highlight server under mouse', TRUE),
),
- 'Configure left frame',
+ 'Configure navigation frame',
'Customize the appears of the navigation frame.',
$defaults);
?>
@@ -1636,7 +1636,7 @@ switch ($action) {
show_relation_form($configuration);
break;
- case 'lay_left_real':
+ case 'lay_navigation_real':
if (isset($_POST['submit_save'])) {
$vals = grab_values('LeftFrameLight:bool;LeftFrameDBTree:bool;LeftFrameDBSeparator;LeftFrameTableSeparator;LeftFrameTableLevel:int;LeftDisplayLogo:bool;LeftDisplayServers:bool;LeftPointerEnable:bool');
$err = FALSE;
@@ -1655,7 +1655,7 @@ switch ($action) {
$show_info = TRUE;
}
break;
- case 'lay_left':
+ case 'lay_navigation':
show_left_form($configuration);
break;
@@ -1941,7 +1941,7 @@ if (!empty($servers)) {
echo '</fieldset>' . "\n\n";
echo '<fieldset class="toolbar"><legend>Layout</legend>' . "\n";
-echo get_action('lay_left', 'Left frame');
+echo get_action('lay_navigation', 'Navigation frame');
echo get_action('lay_tabs', 'Tabs');
echo get_action('lay_icons', 'Icons');
echo get_action('lay_browse', 'Browsing');
diff --git a/js/querywindow.js b/js/querywindow.js
index 3d090b6253..dfd2a0f3b3 100644
--- a/js/querywindow.js
+++ b/js/querywindow.js
@@ -38,7 +38,7 @@ function setDb(new_db) {
}
/**
* sets current selected table (called from left.php)
*
* @param string table name
*/
@@ -80,7 +80,7 @@ function refreshMain(url) {
}
function refreshNavigation() {
- goTo('left.php?server=' + server +
+ goTo('navigation.php?server=' + server +
'&db=' + db +
'&table=' + table +
'&lang=' + lang +
@@ -38,7 +38,7 @@ function setDb(new_db) {
}
/**
- * sets current selected table (called from left.php)
+ * sets current selected table (called from navigation.php)
*
* @param string table name
diff --git a/left.php b/navigation.php
index d76af28da9..b0e34a3bfe 100644
--- a/left.php
+++ b/navigation.php
@@ -48,15 +48,15 @@
require_once './libraries/common.lib.php';
/**
* finish and cleanup left.php script execution
*
* @uses $GLOBALS['controllink'] to close it
* @uses $GLOBALS['userlink'] to close it
* @uses PMA_outBufferPost()
* @uses PMA_DBI_close()
* @access private only to be used in left.php
*/
-function PMA_exitLeftFrame()
+function PMA_exitNavigationFrame()
{
echo '</body></html>';
@@ -159,18 +159,18 @@ require_once './libraries/header_http.inc.php';
require './libraries/left_header.inc.php';
if (! $GLOBALS['server']) {
// no server selected
- PMA_exitLeftFrame();
+ PMA_exitNavigationFrame();
} elseif (! $GLOBALS['PMA_List_Database']->count()) {
// no database available, so we break here
echo '<p>' . $GLOBALS['strNoDatabases'] . '</p>';
- PMA_exitLeftFrame();
+ PMA_exitNavigationFrame();
} elseif ($GLOBALS['cfg']['LeftFrameLight'] && $GLOBALS['PMA_List_Database']->count() > 1) {
// more than one database available and LeftFrameLight is true
// display db selectbox
//
// Light mode -> beginning of the select combo for databases
// Note: When javascript is active, the frameset will be changed from
// within left.php. With no JS (<noscript>) the whole frameset will
// be rebuilt with the new target frame.
?>
@@ -205,7 +205,7 @@ $img_minus = '<img class="icon" id="el%dImg" src="' . $pmaThemeImage . 'b_minus.
.' width="9" height="9" alt="-" />';
$href_left = '<a onclick="if (toggle(\'%d\')) return false;"'
- .' href="left.php?%s" target="_self">';
+ .' href="navigation.php?%s" target="_self">';
$element_counter = 0;
@@ -354,7 +354,7 @@ function PMA_displayDbList($ext_dblist) {
title="<?php echo htmlspecialchars($db['comment']); ?>"
onclick="
if (! toggle('<?php echo $element_counter; ?>', true))
- window.parent.goTo('./left.php?<?php echo $common_url_query; ?>');
+ window.parent.goTo('./navigation.php?<?php echo $common_url_query; ?>');
window.parent.goTo('./<?php echo $GLOBALS['cfg']['DefaultTabDatabase']
. '?' . $common_url_query; ?>', 'main');
return false;">
@@ -499,7 +499,7 @@ function PMA_displayTableList($tables, $visible = false,
target="_parent"
onclick="
if (! toggle('<?php echo $element_counter; ?>', true))
- window.parent.goTo('./left.php?<?php echo $common_url_query; ?>');
+ window.parent.goTo('./navigation.php?<?php echo $common_url_query; ?>');
window.parent.goTo('./<?php echo $GLOBALS['cfg']['DefaultTabDatabase']
. '?' . $common_url_query; ?>', 'main');
return false;">
@@ -564,5 +564,5 @@ function PMA_displayTableList($tables, $visible = false,
}
echo '</div>';
-PMA_exitLeftFrame();
+PMA_exitNavigationFrame();
?>
@@ -48,15 +48,15 @@
require_once './libraries/common.lib.php';
/**
- * finish and cleanup left.php script execution
+ * finish and cleanup navigation.php script execution
*
* @uses $GLOBALS['controllink'] to close it
@@ -48,15 +48,15 @@
* @uses PMA_outBufferPost()
* @uses PMA_DBI_close()
- * @access private only to be used in left.php
+ * @access private only to be used in navigation.php
*/
@@ -159,18 +159,18 @@ require_once './libraries/header_http.inc.php';
// Light mode -> beginning of the select combo for databases
// Note: When javascript is active, the frameset will be changed from
- // within left.php. With no JS (<noscript>) the whole frameset will
+ // within navigation.php. With no JS (<noscript>) the whole frameset will
// be rebuilt with the new target frame.
?>